import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { is, fromJS } from 'immutable'
import { Modal, Button } from 'antd'
import moment from 'moment'

import asyncComponent from '@/utils/asyncComponent'
import { getCardCellForm } from './formconfig'
import { getActionForm, getBaseTableActionForm } from '@/menu/components/share/actioncomponent/formconfig'
import MKEmitter from '@/utils/events.js'
import MenuUtils from '@/utils/utils-custom.js'
import ElementForm from './elementform'
import CreateFunc from '@/templates/zshare/createfunc'
import DragElement from './dragaction'
import './index.scss'

const { confirm } = Modal

const ActionForm = asyncComponent(() => import('@/menu/components/share/actioncomponent/actionform'))
const VerifyCard = asyncComponent(() => import('@/templates/zshare/verifycard'))
const VerifyPrint = asyncComponent(() => import('@/templates/sharecomponent/actioncomponent/verifyprint'))
const VerifyExcelIn = asyncComponent(() => import('@/templates/sharecomponent/actioncomponent/verifyexcelin'))
const VerifyExcelOut = asyncComponent(() => import('@/templates/sharecomponent/actioncomponent/verifyexcelout'))
const VerifyPay = asyncComponent(() => import('@/templates/sharecomponent/actioncomponent/verifypay'))

class CardCellComponent extends Component {
  static propTpyes = {
    cards: PropTypes.object,
    cardCell: PropTypes.object,
    side: PropTypes.string,
    timestamp: PropTypes.any,
    elements: PropTypes.array,
    updateElement: PropTypes.func
  }

  state = {
    appType: sessionStorage.getItem('appType'),
    card: null,          // 编辑中元素
    formlist: null,      // 表单信息
    elements: null,      // 按钮组
    visible: false,      // 模态框控制
    actvisible: false,   // 按钮编辑模态框
    profVisible: false,  // 验证信息编辑
    record: null
  }

  /**
   * @description 搜索条件初始化
   */
  UNSAFE_componentWillMount () {
    const { elements } = this.props
    let _elements = fromJS(elements).toJS()

    this.setState({
      elements: _elements.map(item => {
        if (item.btnstyle) { // 兼容
          item.style = item.style || {}
          item.style = {...item.style, ...item.btnstyle}
          delete item.btnstyle
        }

        return item
      })
    })
  }

  componentDidMount () {
    MKEmitter.addListener('submitModal', this.handleSave)
    MKEmitter.addListener('cardAddElement', this.cardAddElement)
    MKEmitter.addListener('cardDelElement', this.cardDelElement)
    MKEmitter.addListener('submitComponentStyle', this.updateComponentStyle)
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.state), fromJS(nextState)) || !is(fromJS(this.props.cards), fromJS(nextProps.cards))
  }

  UNSAFE_componentWillReceiveProps(nextProps) {
    if (this.props.timestamp !== nextProps.timestamp && nextProps.timestamp) {
      this.setState({
        elements: fromJS(nextProps.elements).toJS()
      })
    }
  }

  /**
   * @description 组件销毁，清除state更新，清除快捷键设置
   */
  componentWillUnmount () {
    this.setState = () => {
      return
    }
    MKEmitter.removeListener('submitModal', this.handleSave)
    MKEmitter.removeListener('cardAddElement', this.cardAddElement)
    MKEmitter.removeListener('cardDelElement', this.cardDelElement)
    MKEmitter.removeListener('submitComponentStyle', this.updateComponentStyle)
  }

  updateComponentStyle = (parentId, keys, style) => {
    const { cardCell } = this.props

    if (cardCell.uuid !== parentId) return

    let _elements = this.state.elements.map(item => {
      if (keys.includes(item.uuid)) {
        return this.resetCardStyle(item, {...item.style, ...style})
      }
      return item
    })

    this.setState({
      elements: _elements
    }, () => {
      this.props.updateElement(_elements)
    })
  }

  cardDelElement = (id, eleId) => {
    const { cardCell } = this.props

    if (id !== cardCell.uuid) return

    this.setState({elements: this.state.elements.filter(item => item.uuid !== eleId)})
  }

  cardAddElement = (id, element, type) => {
    const { cardCell, side } = this.props

    if (id !== cardCell.uuid) return
    if (window.GLOB.$lock) return
    if (type && side !== type) return

    window.GLOB.$lock = true
    setTimeout(() => {
      window.GLOB.$lock = false
    }, 200)

    const { elements } = this.state

    this.setState({elements: [...elements, element]})

    this.handleElement(element)
  }

  handleStyle = (element) => {
    let _style = element.style ? fromJS(element.style).toJS() : {}
    let options = ['font', 'border', 'padding', 'margin', 'background']

    if (element.eleType === 'button') {
      if (element.OpenType === 'form' && element.formType !== 'scan') {
        options = ['margin', 'float']
      } else {
        options.push('width', 'minHeight', 'float')
        if (element.OpenType !== 'form') {
          options.push('display')
        }
        _style.minHeight = _style.minHeight || '28px'
        _style.textAlign = _style.textAlign || 'center'
      }

      if (element.wrapStyle) {
        _style.float = element.wrapStyle.textAlign || 'left'
      } else {
        _style.float = _style.float || 'center'
      }
    } else if (element.eleType === 'picture') {
      options = ['background', 'border', 'margin']
    } else if (element.eleType === 'color') {
      options = ['border', 'margin', 'padding']
    } else if (element.eleType === 'number' || element.eleType === 'icon') {
      options.push('display')
    } else if (element.eleType === 'text') {
      options[0] = 'font2'
      options.push('display')
    } else if (element.eleType === 'slider') {
      options = ['padding', 'margin']
    } else if (element.eleType === 'splitline') {
      options = ['padding', 'margin']
    }
    if (['text', 'number', 'formula', 'currentDate'].includes(element.eleType)) {
      options.push('fontFamily')
      _style.fontFamily = _style.fontFamily ? _style.fontFamily.split(',') : []
    }

    if (element.eleType !== 'button' && element.eleType !== 'tag') {
      options.push('position')
    }

    options.push('clear')

    this.setState({
      card: element
    })

    MKEmitter.emit('changeStyle', options, _style, this.getStyle, 'mk-' + element.eleType)
  }

  getStyle = (style) => {
    const { card, elements } = this.state

    let _card = this.resetCardStyle(card, style)

    let _elements = elements.map(cell => {
      if (cell.uuid === _card.uuid) return _card
      return cell
    })

    this.setState({
      elements: _elements
    }, () => {
      this.props.updateElement(_elements)
    })
  }

  resetCardStyle = (card, style) => {
    let _card = fromJS(card).toJS()

    if (['text', 'number', 'formula', 'currentDate', 'sequence', 'icon'].includes(_card.eleType)) {
      _card.style = fromJS(style).toJS()
      let line = _card.height || null

      if (style.fontFamily) {
        if (style.fontFamily.length === 0) {
          delete _card.style.fontFamily
        } else {
          _card.style.fontFamily = style.fontFamily.join(',')
        }
      }

      if (['currentDate', 'sequence'].includes(_card.eleType) || (_card.eleType === 'icon' && _card.tipType !== 'text')) {
        line = 1
      }

      if (line) {
        let fontSize = 14
        let lineHeight = 1.5

        if (_card.style.fontSize) {
          fontSize = parseInt(_card.style.fontSize)
        }
        if (_card.style.lineHeight) {
          lineHeight = parseFloat(_card.style.lineHeight)
        }

        _card.innerHeight = fontSize * lineHeight * line
      } else {
        _card.innerHeight = 'auto'
      }
    } else if (_card.eleType === 'barcode') {
      _card.style = style

      let fontSize = 14

      if (_card.style.fontSize) {
        fontSize = parseInt(_card.style.fontSize)
      }

      _card.innerHeight = _card.barHeight + (_card.displayValue === 'true' ? fontSize + 2 : 0)
    } else if (_card.eleType === 'button') { // 拆分style
      _card.style = fromJS(style).toJS()

      if (_card.OpenType === 'form') {
        delete _card.style.display
      }

      if (style.float) {
        _card.wrapStyle = {textAlign: style.float}
        delete _card.style.float
      }
      if (style.minHeight === '28px') {
        delete _card.style.minHeight
      }
    } else if (_card.eleType === 'picture') {
      _card.style = style
      delete _card.style.backgroundImage
      delete _card.style.paddingTop
      delete _card.style.paddingBottom
      delete _card.style.paddingLeft
      delete _card.style.paddingRight
    } else {
      _card.style = style
    }

    return _card
  }

  /**
   * @description 按钮顺序调整
   */
  handleList = (list) => {
    this.setState({elements: list}, () => {
      this.props.updateElement(list)
    })
  }

  /**
   * @description 元素编辑，获取元素表单信息
   */
  handleElement = (card) => {
    const { cards, cardCell } = this.props

    if (card.eleType === 'button') {
      this.handleAction(card)
    } else {
      this.setState({
        visible: true,
        card: card,
        formlist: getCardCellForm(card, cards, cardCell)
      })
    }
  }

  /**
   * @description 按钮编辑，获取按钮表单信息
   */
  handleAction = (card) => {
    const { cards, side } = this.props

    let usefulFields = sessionStorage.getItem('permFuncField')
    if (usefulFields) {
      try {
        usefulFields = JSON.parse(usefulFields)
      } catch (e) {
        usefulFields = []
      }
    } else {
      usefulFields = []
    }

    let ableField = usefulFields.join(', ')
    let msg = `函数名称需以${ableField}等字符开始;`
    let functip = <div>
      <p style={{marginBottom: '5px'}}>{msg}</p>
    </div>

    let supId = ''
    if (cards.setting && cards.setting.supModule) {
      let pid = cards.setting.supModule[cards.setting.supModule.length - 1]
      if (pid && pid !== 'empty') {
        supId = pid
      } else {
        supId = ''
      }
    }
    let menu = window.GLOB.customMenu

    let modules = MenuUtils.getSubModules(menu.components, cards.uuid, supId, menu.interfaces || null)

    if (cards.subtype === 'basetable') {
      this.setState({
        actvisible: true,
        card: card,
        formlist: getBaseTableActionForm(card, functip, cards, usefulFields, modules, 'line')
      })
    } else {
      let anchors = MenuUtils.getAnchors(menu.components, cards.uuid) || []

      this.setState({
        actvisible: true,
        card: card,
        formlist: getActionForm(card, functip, cards, usefulFields, modules, anchors, side, 'line')
      })
    }
  }

  /**
   * @description 取消保存，如果元素为新添元素，则从序列中删除
   */
  editModalCancel = () => {
    const { card, elements } = this.state
    let _elements = null

    if (card.focus) {
      _elements = elements.filter(item => item.uuid !== card.uuid)
    } else {
      _elements = elements
    }

    this.setState({
      card: null,
      elements: _elements,
      visible: false,
      actvisible: false
    }, () => {
      this.props.updateElement(_elements)
    })
  }

  /**
   * @description 元素修改后提交保存
   */
  handleSubmit = () => {
    const { elements } = this.state

    this.elementFormRef.handleConfirm().then(res => {
      if (res.width % 0.5) {
        res.width = parseInt(res.width / 0.5) * 0.5
      }
      if (res.width % 1) {
        res.width = (res.width + '').replace(/.5/, 'x')
      }

      if (res.eleType === 'formula' && res.eval === 'false' && res.noValue === 'hide') {
        let keys = res.formula.match(/@[0-9a-z_]+@/ig)
        if (keys) {
          res.$keys = keys.map(key => key.slice(1, -1).toLowerCase())
          res.$keys = Array.from(new Set(res.$keys))
        }
      }

      let _elements = elements.map(cell => {
        if (cell.uuid === res.uuid) {
          res.style = cell.style || {}

          if (!['text', 'number', 'icon'].includes(res.eleType)) {
            delete res.style.display
          }
          if (!['text', 'number', 'formula', 'currentDate'].includes(res.eleType)) {
            delete res.style.fontFamily
          }
          
          if (res.eleType === 'splitline' && (cell.eleType !== 'splitline' || cell.focus)) {
            res.style.paddingTop = '5px'
            res.style.paddingBottom = '5px'
          } else if (['text', 'number', 'formula', 'currentDate', 'sequence', 'icon'].includes(res.eleType)) {
            let line = res.height || null

            if (['currentDate', 'sequence'].includes(res.eleType) || (res.eleType === 'icon' && res.tipType !== 'text')) {
              line = 1
            }

            if (line) {
              let fontSize = 14
              let lineHeight = 1.5

              if (res.style && res.style.fontSize) {
                fontSize = parseInt(res.style.fontSize)
              }
              if (res.style && res.style.lineHeight) {
                lineHeight = parseFloat(res.style.lineHeight)
              }

              res.innerHeight = fontSize * lineHeight * line
            } else {
              res.innerHeight = 'auto'
            }

            if (res.eleType === 'text' && res.link && !res.style.color) {
              res.style.color = '#2440B3'
            }
          } else if (res.eleType === 'barcode') {
            let fontSize = 14
      
            if (res.style && res.style.fontSize) {
              fontSize = parseInt(res.style.fontSize)
            }
      
            res.innerHeight = res.barHeight + (res.displayValue === 'true' ? fontSize + 2 : 0)
          } else if (res.eleType === 'picture') {
            delete res.style.backgroundImage
            delete res.style.paddingTop
            delete res.style.paddingBottom
            delete res.style.paddingLeft
            delete res.style.paddingRight
          } else if (res.eleType === 'tag') {
            delete res.style.position
            if (cell.eleType !== 'tag') {
              res.style = {
                backgroundColor: 'var(--mk-sys-color1)',
                color: 'var(--mk-sys-color)',
                borderColor: 'var(--mk-sys-color)',
                borderWidth: '1px',
                borderRadius: '4px',
                paddingLeft: '7px',
                paddingRight: '7px',
                marginRight: '8px',
                marginBottom: '8px',
              }
            }
          }
          
          return res
        }
        return cell
      })

      this.setState({
        elements: _elements,
        visible: false
      }, () => {
        this.props.updateElement(_elements)
      })
    })
  }

  /**
   * @description 元素修改后提交保存
   */
  handleActionSubmit = () => {
    const { elements } = this.state
    let color = { primary: '#1890ff', yellow: '#c49f47', orange: 'orange', danger: '#ff4d4f', green: '#26C281', dgreen: '#32c5d2', purple: '#8E44AD', cyan: '#13c2c2', gray: '#666666', default: 'rgba(0, 0, 0, 0.65)' }

    this.actionFormRef.handleConfirm().then(res => {
      if (res.width % 0.5) {
        res.width = parseInt(res.width / 0.5) * 0.5
      }
      if (res.width % 1) {
        res.width = (res.width + '').replace(/.5/, 'x')
      }
      
      let _elements = elements.map(cell => {
        if (cell.uuid === res.uuid) {
          res.eleType = cell.eleType || null
          res.style = cell.style || null
          res.wrapStyle = cell.wrapStyle || null

          if (res.OpenType === 'form') {
            if (cell.OpenType !== 'form') {
              res.style = {}
            }

            if (res.style) {
              delete res.style.display
            }
          // } else if (res.class !== cell.class || res.show !== cell.show || !res.style) {
          } else if (res.class !== cell.class || !res.style) {
            if (res.class) {
              let cl = res.class.replace('border-', '')
              let style = {}
              if (res.class === 'default') {
                style.color = 'rgba(0, 0, 0, 0.65)'
                style.backgroundColor = 'transparent'
                style.borderColor = '#d9d9d9'
              } else if (res.class.indexOf('border') > -1) {
                style.color = color[cl]
                style.backgroundColor = 'transparent'
                style.borderColor = color[cl]
              } else {
                style.color = '#ffffff'
                style.backgroundColor = color[cl]
              }
              res.style = {...res.style, ...style}
            } else {
              res.style = res.style || {}
            }
          }

          if (res.width === 0 && cell.width !== 0) {
            res.style = res.style || {}

            res.style.paddingLeft = '15px'
            res.style.paddingRight = '15px'
            res.style.marginRight = '15px'
            res.style.width = 'auto'

            delete res.style.marginLeft
          }

          res.updateTime = moment().format('YYYY-MM-DD HH:mm')

          return res
        }
        return cell
      })

      this.setState({
        elements: _elements,
        actvisible: false
      }, () => {
        this.props.updateElement(_elements)
      })
    })
  }

  /**
   * @description 按钮删除
   */
  deleteElement = (card) => {
    const { elements } = this.state
    let that = this

    confirm({
      content: '确定删除元素吗？',
      onOk() {
        let _elements = elements.filter(item => item.uuid !== card.uuid)

        that.setState({
          elements: _elements
        }, () => {
          that.props.updateElement(_elements)
        })
      },
      onCancel() {}
    })
  }

  /**
   * @description 验证信息配置
   */
  profileAction = (element) => {
    this.setState({
      profVisible: true,
      card: element
    })
  }

  /**
   * @description 验证信息保存
   */
  verifySubmit = () => {
    const { elements, card } = this.state

    this.verifyRef.handleConfirm().then(res => {
      res.customverifys && res.customverifys.forEach(item => {
        item.sql = item.sql.replace(/\t+|\v+/g, ' ')
      })
      res.scripts && res.scripts.forEach(item => {
        item.sql = item.sql.replace(/\t+|\v+/g, ' ')
      })
      res.cbScripts && res.cbScripts.forEach(item => {
        item.sql = item.sql.replace(/\t+|\v+/g, ' ')
      })
      
      let _elements = elements.map(cell => {
        if (cell.uuid === card.uuid) {
          cell.verify = res
          cell.updateTime = moment().format('YYYY-MM-DD HH:mm')
        }

        return cell
      })

      this.setState({
        elements: _elements,
        profVisible: false
      }, () => {
        this.props.updateElement(_elements)
      })
    })
  }

  handleSubConfig = (item) => {
    const { cards, side } = this.props
    const { appType } = this.state
    let btn = fromJS(item).toJS()

    if (side === 'sub') {
      btn.$sub = true
    }

    if ((sessionStorage.getItem('style-control') && sessionStorage.getItem('style-control') === 'true')) return

    if (btn.OpenType === 'pop' || btn.execMode === 'pop') {
      if (!btn.modal) {
        btn.modal = {
          setting: { title: btn.label, width: appType === 'mob' ? 100 : 60, cols: '2', container: 'view', focus: '', finish: 'close', clickouter: 'unclose', display: 'modal' },
          tables: [],
          groups: [],
          fields: []
        }
      }

      MKEmitter.emit('changeModal', cards, btn)
    } else if (btn.OpenType === 'popview') {
      MKEmitter.emit('changePopview', cards, btn)
    } else if (btn.OpenType === 'innerpage' && btn.pageTemplate === 'linkpage') {
      MKEmitter.emit('changeEditMenu', {MenuID: btn.linkmenu})
    } else if (btn.OpenType === 'funcbutton' && (btn.funcType === 'copyurl' || btn.funcType === 'scan') && btn.linkmenu) {
      MKEmitter.emit('changeEditMenu', {MenuID: btn.linkmenu})
    } else {
      this.handleElement(item)
    }
  }

  handleSave = (componentId, btnId, modal) => {
    const { cards } = this.props
    const { elements } = this.state

    if (cards.uuid !== componentId) return
    
    let _index = elements.findIndex(cell => cell.uuid === btnId)

    if (_index === -1) return

    let _elements = elements.map(cell => {
      if (cell.uuid === btnId) {
        cell.modal = modal
      }

      return cell
    })

    this.setState({
      elements: _elements
    }, () => {
      this.props.updateElement(_elements)
    })
  }

  updateMarks = (card) => {
    const { elements } = this.state

    let _elements = elements.map(cell => {
      if (cell.uuid === card.uuid) return card
      return cell
    })

    this.setState({
      elements: _elements
    }, () => {
      this.props.updateElement(_elements)
    })
  }

  dropButton = (id) => {
    const { cards } = this.props

    if (!cards.action) return

    let index = cards.action.findIndex(item => item.uuid === id)

    if (index === -1) return

    let btn = cards.action[index]
    btn.eleType = 'button'

    if (!btn.width) {
      btn.width = 12
    }
    if (btn.color) {
      btn.style = btn.style || {}
      btn.style.color = '#ffffff'
      if (btn.color === 'primary') {
        btn.style.backgroundColor = '#1677ff'
      } else if (btn.color === 'danger') {
        btn.style.backgroundColor = '#ff3141'
      } else if (btn.color === 'warning') {
        btn.style.backgroundColor = '#ff8f1f'
      } else if (btn.color === 'success') {
        btn.style.backgroundColor = '#00b578'
      } else if (btn.color === 'light') {
        btn.style.backgroundColor = '#cccccc'
      }
    }

    let _elements = [...this.state.elements, btn]

    this.setState({
      elements: _elements
    }, () => {
      this.props.updateElement(_elements, btn)
    })
  }

  /**
   * @description 创建按钮存储过程
   */
  creatFunc = () => {
    const { cards } = this.props
    const menu = window.GLOB.customMenu

    return new Promise((resolve) => {
      this.actionFormRef.handleConfirm().then(res => {
        let btn = fromJS(res).toJS()
        let _config = fromJS(cards).toJS()

        if (btn.OpenType === 'excelIn') {
          btn.func = btn.innerFunc
          btn.menuNo = menu.MenuNo
          btn.MenuName = menu.MenuName + _config.name
          btn.$type = 'excelIn'

          resolve(btn)
        } else if (btn.OpenType === 'excelOut') {
          _config.MenuName = menu.MenuName + '-' + _config.name
          _config.menuNo = menu.MenuNo
          _config.MenuID = menu.MenuID
          _config.func = btn.innerFunc
          _config.$type = 'table'
          
          resolve(_config)
        } else {
          btn.func = btn.innerFunc
          btn.name = _config.setting.tableName || ''
          btn.menuNo = menu.MenuNo
          btn.MenuID = menu.MenuID
          btn.MenuName = menu.MenuName + _config.name
          btn.fields = []
          btn.columns = _config.columns
          btn.primaryKey = _config.setting.primaryKey || 'ID'
          btn.$type = 'btn'

          if (btn.OpenType === 'pop') {
            btn.fields = btn.modal ? btn.modal.fields : []
          }

          resolve(btn)
        }
      })
    })
  }

  getVerify = (card) => {
    const { cards, side } = this.props

    if (!card) return null

    if (['pop', 'prompt', 'exec', 'form'].includes(card.OpenType)) {
      return <VerifyCard
        card={card}
        config={cards}
        side={side || ''}
        columns={side === 'sub' ? cards.subColumns : cards.columns}
        wrappedComponentRef={(inst) => this.verifyRef = inst}
      />
    } else if (card.OpenType === 'excelIn') {
      return <VerifyExcelIn
        card={card}
        columns={side === 'sub' ? cards.subColumns : cards.columns}
        wrappedComponentRef={(inst) => this.verifyRef = inst}
      />
    } else if (card.OpenType === 'excelOut') {
      return <VerifyExcelOut
        card={card}
        config={cards}
        wrappedComponentRef={(inst) => this.verifyRef = inst}
      />
    } else if (card.OpenType === 'funcbutton' && card.funcType === 'print') {
      return <VerifyPrint
        card={card}
        columns={side === 'sub' ? cards.subColumns : cards.columns}
        wrappedComponentRef={(inst) => this.verifyRef = inst}
      />
    } else if (card.payMode === 'system') {
      return <VerifyPay
        card={card}
        columns={side === 'sub' ? cards.subColumns : cards.columns}
        wrappedComponentRef={(inst) => this.verifyRef = inst}
      />
    }
  }

  render() {
    const { cards, cardCell, side } = this.props
    const { elements, visible, actvisible, profVisible, card, record } = this.state

    return (
      <div className={'model-menu-card-cell-list ' + (cardCell && cardCell.setting && cardCell.setting.layout === 'flex' ? 'mk-flex' : '') }>
        <DragElement
          list={elements}
          parent={cardCell}
          fields={side === 'sub' ? cards.subColumns : cards.columns}
          updateMarks={this.updateMarks}
          handleList={this.handleList}
          handleMenu={this.handleElement}
          handleStyle={this.handleStyle}
          dropButton={this.dropButton}
          profileAction={this.profileAction}
          handleSubConfig={this.handleSubConfig}
          deleteMenu={this.deleteElement}
        />
        <div onDoubleClick={(e) => e.stopPropagation()}>
          {/* 编辑按钮：复制、编辑 */}
          <Modal
            title="编辑元素"
            wrapClassName="mk-scroll-modal"
            visible={visible}
            width={850}
            maskClosable={false}
            onCancel={this.editModalCancel}
            onOk={this.handleSubmit}
            destroyOnClose
          >
            <ElementForm
              card={card}
              side={side}
              formlist={this.state.formlist}
              inputSubmit={this.handleSubmit}
              config={cards}
              wrappedComponentRef={(inst) => this.elementFormRef = inst}
            />
          </Modal>
          {/* 编辑按钮：复制、编辑 */}
          <Modal
            title="按钮·编辑"
            wrapClassName="mk-scroll-modal"
            visible={actvisible}
            width={920}
            maskClosable={false}
            onCancel={this.editModalCancel}
            footer={[
              record && record.intertype === 'inner' && cards.subtype === 'dualdatacard' ? <CreateFunc key="create" getMsg={this.creatFunc}/> : null,
              <Button key="cancel" onClick={this.editModalCancel}>取消</Button>,
              <Button key="confirm" type="primary" onClick={this.handleActionSubmit}>确定</Button>
            ]}
            destroyOnClose
          >
            <ActionForm
              type={cards.type === 'balcony' || cardCell.$cardType === 'extendCard' ? '' : 'card'}
              card={card}
              formlist={this.state.formlist}
              inputSubmit={this.handleActionSubmit}
              setting={cards.setting}
              updRecord={(record) => this.setState({record: fromJS(record).toJS()})}
              wrappedComponentRef={(inst) => this.actionFormRef = inst}
            />
          </Modal>
          {/* 按钮使用系统存储过程时，验证信息模态框 */}
          <Modal
            wrapClassName="mk-pop-modal"
            visible={profVisible}
            width={'90vw'}
            maskClosable={false}
            okText="提交"
            onOk={this.verifySubmit}
            onCancel={() => {
              if (this.verifyRef.handleCancel) {
                this.verifyRef.handleCancel().then(() => {
                  this.setState({ profVisible: false })
                })
              } else {
                this.setState({ profVisible: false })
              }
            }}
            destroyOnClose
          >
            {this.getVerify(card)}
          </Modal>
        </div>
      </div>
    )
  }
}

export default CardCellComponent